@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //*************************************************************************
 //
-// Copyright 2009-2009 by Wilson Snyder.  This program is free software;
+// Copyright 2009-2011 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the
 // GNU Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
@@ -47,6 +47,7 @@ public:
 	UNKNOWN = 3,	// Things that need scope, but don't know type yet
 	//
 	BLOCK,
+	CHECKER,
 	CLASS,		// For yaID__CLASS
 	CLOCKING,
 	COVERGROUP,	// For yaID__COVERGROUP
@@ -54,6 +55,8 @@ public:
 	FORK,
 	FUNCTION,
 	INTERFACE,
+	LET,
+	MODPORT,
 	MODULE,
 	PACKAGE,	// For yaID__PACKAGE
 	PROGRAM,
@@ -73,9 +76,9 @@ public:
     const char* ascii() const {
 	static const char* names[] = {
 	"NOT_FOUND", "netlist", "error", "unknown",
-	"block", "class", "clocking", "covergroup",
-	"enum", "fork", "function", "interface",
-	"module", "package", "program", "property",
+	"block", "checker", "class", "clocking", "covergroup",
+	"enum", "fork", "function", "interface", "let",
+	"modport", "module", "package", "program", "property",
 	"sequence", "struct", "task", "type", "union",
 	"_MAX"
 	};
@@ -99,8 +102,8 @@ private:
 public:
     static void debug(int flag) { s_debug=flag; }
     static int debug() { return s_debug; }
-private:
 
+private:
     // CREATORS
     VAstEnt() { assert(0); }	// Not made by users, it's an AV*
     ~VAstEnt() { assert(0); }	// Not made by users, it's an AV*
@@ -116,7 +119,7 @@ private:
     struct hv* subhash();
 
     /// Insert into current table
-    void insert(VAstEnt* newentp, const string& name);
+    void replaceInsert(VAstEnt* newentp, const string& name);
 
 public:
     // ACCESSORS
@@ -137,11 +140,11 @@ public:
     /// Return internal pointer for given name or null
     VAstEnt* findSym (const string& name);
 
-    /// Insert into current table
-    VAstEnt* insert(VAstType type, const string& name);
+    /// Find or create a symbol under current entry
+    VAstEnt* findInsert (VAstType type, const string& name);
 
-    /// Find or create a symbol entry under current entry
-    VAstEnt* findNewTable (VAstType type, const string& name);
+    /// Replace or create a symbol entry under current entry
+    VAstEnt* replaceInsert (VAstType type, const string& name);
 
     /// Insert into current table from another imported package's table
     void import(VAstEnt* fromEntp, const string& id_or_star);
